==> segatex-8.500.tar.gz: segatex-8.500/src/miscellaneous_process.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef MISCELLANEOUSPROCESS_H
#define MISCELLANEOUSPROCESS_H

#include <qdir.h> 

#include "miscellaneous.h" 

class Miscellaneous;

class MiscellaneousProcess: public QDialog 
{
	Q_OBJECT
public:
	MiscellaneousProcess(QWidget *parent = 0, const char *name = 0);
	Miscellaneous *selinux_audit2allow_common_obj;
	int i;
	QString outputfile_str_common;
public slots:
	void audit2allow_base_process(int log_file, QString outputfile_str, int options, QString moduleName_str);
signals:
	void audit2allow_prosess_close_button_clicked();
protected:

private slots:
	void close_button_clicked();
	void readFromStdout();
	void processExited();
	void readFromOutputFile();
public:
private:
	QPushButton *closeButton;
	QTextEdit *textEdit1;
	QProcess *process;
	Miscellaneous *selinux_audit2allow;
	MiscellaneousProcess *selinux_audit2allow_process;
	int a,b,c,x,y,xx,yy,xxx,yyy,xxxx,yyyy;

        QDir dir;
        QString path;
        QString name;
        QString dir_name;
        QString forward_slash;
        QString file_interface_name;
        QString line_analized;

        QStringList::Iterator it_d;
        QStringList files;

};

#endif

==> segatex-8.630.tar.gz: segatex-8.630/src/miscellaneous_process.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef MISCELLANEOUSPROCESS_H
#define MISCELLANEOUSPROCESS_H

#include <QDir> 
#include <QVBoxLayout> 
#include <QHBoxLayout>
 
#include "miscellaneous.h" 

class Miscellaneous;

class MiscellaneousProcess: public QDialog 
{
	Q_OBJECT
public:
	MiscellaneousProcess(QWidget *parent = 0, const char *name = 0);
	Miscellaneous *selinux_audit2allow_common_obj;
	int i;
	QString outputfile_str_common;
public slots:
	void audit2allow_base_process(int log_file, QString outputfile_str, int options, QString moduleName_str);
signals:
	void audit2allow_prosess_close_button_clicked();
protected:

private slots:
	void close_button_clicked();
	void readFromStdout();
	void processExited();
	void readFromOutputFile();
public:
private:
	QPushButton *closeButton;
	QTextEdit *textEdit1;
	QProcess *process;
	Miscellaneous *selinux_audit2allow;
	MiscellaneousProcess *selinux_audit2allow_process;
	int a,b,c,x,y,xx,yy,xxx,yyy,xxxx,yyyy;

        QDir dir;
        QString path;
        QString name;
        QString dir_name;
        QString forward_slash;
        QString file_interface_name;
        QString line_analized;
        QString process_str;
        QString process_str_base;
        QString process_str_option;
        QVBoxLayout *headLayout;
        QHBoxLayout *footLayout;
        QVBoxLayout *mainLayout;

        QStringList::Iterator it_d;
        QStringList files;

};

#endif
